@@ -8,7 +8,7 @@ use Digest::MD5 ();
 use Storable    ();
 use Cwd         ();
 
-our $VERSION = q{0.314};
+our $VERSION = q{0.314002};
 
 # constructor
 sub new {
@@ -340,6 +340,12 @@ memory programming to the uniprocess environment that is C<perl>.
 After all, if we're going to I<fake the funk out of coroutines> [4],
 let's do it correctly. C<:)>
 
+[6], an exposition of L<sequential consistency> in the I<Chapel> programming
+language also provides quite an interesting read. Chapel itself is
+interested, as are the other I<high productivity> high performance
+computing languages that came out during the first decade of this century
+(X10, Fortress, etc).
+
 =head1 SYNOPSIS
 
     # D E F I N E  T H E  P L A N
@@ -1240,6 +1246,8 @@ Executes Multiprocess Programs", IEEE Trans. Comput. C-28,9 (Sept. 1979), 690-69
 =item * 5. Introduction to Automata Theory, Languages, and Computation; Hopcroft, Motwani,
 Ullman. Any year.
 
+=item * 6. L<https://chapel-lang.org/docs/language/spec/memory-consistency-model.html#sequential-consistency-for-data-race-free-programs>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
